@@ -1,7 +1,7 @@
 #ifndef CONFIG_H_
 #define CONFIG_H_
 
-#define CPPUTEST_MEM_LEAK_DETECTION_DISABLED
+/* #undef CPPUTEST_MEM_LEAK_DETECTION_DISABLED */
 /* #undef CPPUTEST_USE_LONG_LONG */
 
 /* #undef CPPUTEST_STD_C_LIB_DISABLED */
